<?php

/**
 * @file
 * Administrative functions for MaPS module.
 */

use Drupal\maps\Log\LogInterface;

/**
 * Menu callback; administrative overview.
 */
function maps_admin_overview() {
  $rows = array();

  foreach (module_invoke_all('maps_admin_overview') as $header => $content) {
    $row = array();
    $row[] = array(
      'header' => TRUE,
      'data' => $header,
    );

    if (is_array($content)) {
      $row = array_merge($row, $content);
    }
    else {
      $row[] = array(
        'data' => $content,
        'colspan' => 3,
      );
    }

    $rows[] = $row;
  }

  drupal_alter('maps_admin_overview', $rows);
  return theme('table', array('rows' => $rows));
}

/**
 * Form API; Form builder for MaPS Log settings.
 */
function maps_admin_log_form($form, &$form_state) {
  // Settings.
  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings'),
  );

  $form['settings']['maps_log_path'] = array(
    '#title' => t('Path to log files'),
    '#type' => 'textfield',
    '#default_value' => variable_get('maps_log_path', LogInterface::LOG_DIR),
    '#description' => t('Define the path to the log files relative to Drupal file directory.'),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Form API; Submit the log form.
 */
function maps_admin_log_form_submit($form, &$form_state) {
  // Settings.
  variable_set('maps_log_path', $form_state['values']['maps_log_path']);
}
