<?php

/**
 * @file
 * Class that represents a converter of type media.
 */

namespace Drupal\maps_import\Converter;

use Drupal\maps_import\Mapping\Media as MappingMedia;
use Drupal\maps_import\Mapping\Source\MapsSystem\Entity;

class Media extends Converter {

  /**
   * @inheritdoc
   *
   * Provide the code property as default value for the converter add form.
   */
  private $uid = 'property:code';

  /**
   * @inheritdoc
   */
  public function entityInfo() {
    return array_intersect_key(parent::entityInfo(), array_flip(array('file')));
  }

  /**
   * @inheritdoc
   */
  public function getMapping() {
    return new MappingMedia($this);
  }

  /**
   * @inheritdoc
   */
  public function getType() {
    return 'media';
  }

  /**
   * @inheritdoc
   */
  public function isMappingAllowed() {
    $media_types = maps_import_get_maps_media_types($this->getProfile());
    $options = $this->getProfile()->getOptions();

    foreach ($media_types as $key => $media_type) {
      if (empty($options['media_settings'][$key]['path'])
        || !is_dir("public://{$this->getProfile()->getMediaDirectory()}/{$options['media_settings'][$key]['path']}")) {
        return FALSE;
      }
    }

    return TRUE;
  }
}
