<?php

/**
 * @file
 * Handle objects mapping operation.
 */

namespace Drupal\maps_import\Mapping\Mapper;

use Drupal\maps_import\Fetcher\Fetcher;
use Drupal\maps_import\Mapping\Source\MapsSystem\Object as MapsSystemObject;

/**
 * Base class for all mapping operations.
 */
class Object extends Mapper {

  /**
   * @inheritdoc
   */
  public function getTitle() {
    return t('Objects mapping');
  }

  /**
   * @inheritdoc
   */
  public function getDescription() {
    return t('The objects mapping operation is related to the profile %profile.', array('%profile' => $this->getProfile()->getTitle()));
  }

  /**
   * @inheritdoc
   */
  public function getType() {
    return 'object_mapping';
  }

  /**
   * @inheritdoc
   */
  protected function getConverterClass() {
    return "Drupal\\maps_import\\Converter\\Object";
  }

  /**
   * @inheritdoc
   */
  protected function getEntityTable() {
    return Fetcher::DB_OBJ_TABLE;
  }

  /**
   * @inheritdoc
   */
  protected function createEntity(array $entity) {
    return new MapsSystemObject($entity);
  }

  /**
   * Get the current list of object entities to process
   * and add related medias to objects.
   */
  protected function getCurrentEntities($maxEntities) {
    $objects = parent::getCurrentEntities($maxEntities);

    if (empty($objects)) {
      return $objects;
    }

    $query = db_select('maps_import_object_media')
      ->fields('maps_import_object_media', array('media_id', 'object_id'))
      ->condition('object_id', array_keys($objects));

    $medias_alias = $query->join('maps_import_medias', NULL, 'maps_import_object_media.media_id = %alias.id');

    $query
      ->fields($medias_alias, array('type', 'attributes', 'weight'))
      ->condition("$medias_alias.pid", (int) $this->getProfile()->getPid());

    $media_ids_= $query->join('maps_import_media_ids', NULL, "%alias.maps_id = $medias_alias.id");
    $entities_alias = $query->join('maps_import_entities', NULL, "maps_import_media_ids.correspondence_id = %alias.id");

    $query->fields($entities_alias, array('entity_id'));

    $medias = $query
      ->execute()
      ->fetchAllAssoc('media_id', \PDO::FETCH_ASSOC);

    foreach ($objects as $id => &$object) {
      foreach ($medias as $media) {
        if ((int) $media['object_id'] == (int) $id) {
          $object['medias'][] = $media;
        }
      }
    }

    return $objects;
  }

}
