<?php

/**
 * @file
 * Class that defines a Drupal file Entity.
 */

namespace Drupal\maps_import\Mapping\Target\Drupal;

use Drupal\maps_import\Exception\MappingException;
use Drupal\maps_import\Mapping\Mapping;

class File extends Entity {

  /**
   * @inheritdoc
   */
  protected function getTranslationClass() {
    return 'Drupal\\maps_import\\Mapping\\Target\\Drupal\\Translation\\FieldTranslation';
  }

  /**
   * @inheritdoc
   */
  protected function createEntity($languageId, $entityId = NULL) {
    // Get media information from database.
    $entity = Mapping::getCurrentEntity();
    $object = $entity->getRelatedEntities();
    $object = reset($object);
    
    if (!isset($object['filename']) || ! strlen($object['filename'])) {
      throw new MappingException('The media filename is missing.');
    }

    if ($wrapper = parent::createEntity($languageId, $entityId)) {

      // Preset management
      $preset = '';
      $options = $this->getProfile()->getOptions();
      if ($this->getBundle() === 'image') {
        $presets = maps_import_image_presets($this->getProfile());
        $preset = $presets[$options['media_settings'][$object['type']]['preset']] . '/';
      }

      // Media type management.
      $media_types = maps_import_get_maps_media_types($this->getProfile());

      $uri = "public://{$this->getProfile()->getMediaDirectory()}/{$options['media_settings'][$object['type']]['path']}/{$preset}{$object['filename']}";
      $file = $wrapper->value();

      // Remove the fid property, so if it's a new File, Drupal make a insert request.
      if (isset($file->fid)) {
        unset($file->fid);
      }

      if (empty($uri)) {
      	return NULL;
      }
      
      if (!file_exists($uri)) {
        throw new MappingException('The media @uri does not exist.', 0, array('@uri' => $uri));
      }

      // Is this file already stored in the managed files?
      if (empty($file->fid) && $fid = $this->getExistingManagedFiles($uri)) {
        $file->fid = $fid;
      }

      // @todo Handle file user property.
      $file->filename = $object['filename'];
      $file->uri = $uri;
      $file->filemime = file_get_mimetype($uri);
      $file->filesize = filesize($uri);
      $file->status  = FILE_STATUS_PERMANENT;

      return $wrapper;
    }

    return NULL;
  }

  /**
   * Get the existing managed files.
   * 
   * @param $uri
   *   The condition uri.
   */
  protected function getExistingManagedFiles($uri) {
    $result = db_select('file_managed')
      ->fields('file_managed')
      ->condition('uri', $uri)
      ->execute()
      ->fetchAll();

    if (empty($result)) {
      return FALSE;
    }

    $file = reset($result);
    return $file->fid;
  }

}
