<?php

/**
 * @file
 * Class that defines a Drupal file Entity.
 */

namespace Drupal\maps_import\Mapping\Target\Drupal;

use Drupal\maps_links\Mapping\Link;
use Drupal\maps_import\Mapping\Mapper\Mapper;
use Drupal\maps\Log\Logger;
use Drupal\maps\Log\Context\Context as LogContext;

class Relation extends Entity {

  /**
   * @inheritdoc
   */
  protected function getTranslationClass() {
    return 'Drupal\\maps_import\\Mapping\\Target\\Drupal\\Translation\\NoTranslation';
  }

  /**
   * @inheritdoc
   */
  public function save() {
    $entity = Link::getCurrentEntity();

    // Get Drupal entities.
    $sourceEntity = Link::getEntityFromMapsId('object', $entity->getSource());
    $targetEntity = Link::getEntityFromMapsId('object', $entity->getTarget());

    if (!$sourceEntity || !$targetEntity) {
    	return FALSE;
    }
    else {
    	$sourceEntity = reset($sourceEntity);
    	$targetEntity = reset($targetEntity);
    }

    // Set endpoints
    foreach ($this->getEntities() as $wrapper) {
    	$wrapper->endpoints->set(array(
        entity_metadata_wrapper($sourceEntity['entity_type'], entity_load_single($sourceEntity['entity_type'], $sourceEntity['entity_id'])),
        entity_metadata_wrapper($targetEntity['entity_type'], entity_load_single($targetEntity['entity_type'], $targetEntity['entity_id'])),
      ));
    }

    // Log endpoints.
    Mapper::log()
      ->moveToParent('target')
      ->addContext(new LogContext('endpoints'), 'child')
      ->addContext(new LogContext('source'), 'child')->addMessage($sourceEntity['entity_id'])->moveToParent()
      ->addContext(new LogContext('target'), 'child')->addMessage($targetEntity['entity_id']);

    parent::save();
  }

}
