<?php

namespace Drupal\maps_links\Mapping;

use Drupal\maps\Log\Context\Context as LogContext;
use Drupal\maps_import\Mapping\Mapping;
use Drupal\maps_import\Mapping\Mapper\Mapper;
use Drupal\maps_import\Mapping\Source\MapsSystem as MS;
use Drupal\maps_import\Mapping\Target\Drupal\Relation;

class Link extends Mapping {

	/**
	 * The entities correspondance table.
	 */
	const DB_ENTITIES_TABLE = 'maps_links_entities';
	
  /**
   * @inheritdoc
   */ 
  protected $type = 'link_mapping';

  /**
   * @inheritdoc
   */
  public function getSourceProperties() {
    // @todo use a cache class.
    // @todo handle languages
    static $properties;

    if (!isset($properties)) {
      $properties = parent::buildSourcePropertyHandlers(array(
        'count' => array('title' => 'Count'),
      ));
    }

    return $properties;
  }

  /**
   * @inheritdoc
   * @todo implement log. 
   */
  public function process(MS\Entity $entity) {
    self::$currentEntity = $entity;

    // Log source and target properties
    Mapper::log()
      ->addContext(new LogContext('source'), 'child')->addContext(new LogContext('properties'), 'child')
      ->addContext(new LogContext('source_object'), 'child')->addContext(new LogContext('value'), 'child')->addMessage($entity->getSource())
      ->moveToParent('properties')
      ->addContext(new LogContext('target_object'), 'child')->addContext(new LogContext('value'), 'child')->addMessage($entity->getTarget())
      ->moveToParent('properties');
      
    try {    	
      // Set raw values in MaPS Entity.
      foreach ($this->getItems() as $item) {
        $entity->setRawValues($item->getProperty(), $item->getOptions());
      }
        
      Mapper::log()
        ->moveToParent('source')
        ->moveToParent()
        ->addContext(new LogContext('target'), 'child')
        ->addContext(new LogContext('fields'), 'child');
            
      // Create a new Drupal Entity.
      $drupalEntity = new Relation($this->getConverter(), array());

      // Set values in Drupal Entity.
      foreach ($this->getItems() as $item) {
        $drupalEntity->getTranslationHandler()->setValue($item->getField(), $item->getProperty(), $entity, $item->isRequired());
      }
      
	    try { 
        $drupalEntity->save();      
        $identifiers = $drupalEntity->getIdentifiers();

        foreach ($identifiers as $identifier) {
        	db_insert(self::DB_ENTITIES_TABLE)
        	  ->fields(array(
              'pid' => $this->getConverter()->getProfile()->getPid(),
              'cid' => $this->getConverter()->getCid(),
        	    'entity_id' => $identifier,
        	  ))
        	  ->execute();
        }        
	    }
	    catch (MappingException $e) {	      
	      return array(); 
	    }
		    
	    return array($entity, $drupalEntity);
	  }
    catch (MappingException $e) {
      return array(); 
    }  
  }
  
  /**
   * @inheritdoc
   */
  public function getTargetFields() {
  	$fields = parent::getTargetFields();
  	unset($fields['endpoints']);
  	return $fields;
  } 
}
